==> socat-1.1.0.0.tar.bz2: socat-1.1/xio-fd.c <==
static const char _rcsid_[]="$Id: xio-fd.c,v 1.14 2002/05/19 08:09:04 gerhard Exp $";
/* Copyright Gerhard Rieger 2001, 2002 */
/* Published under the GNU General Public License V.2, see file COPYING */

/* this file contains common file descriptor related option definitions */

#include "xiosysincludes.h"
#include "xioopen.h"

#include "xio-fd.h"

/****** for ALL addresses - with open() or fcntl(F_SETFL) ******/
const struct optdesc opt_append    = { "append",    NULL, OPT_APPEND,    GROUP_OPEN|GROUP_FD, PH_LATE, TYPE_BOOL, OFUNC_FCNTL, F_SETFL, O_APPEND };
const struct optdesc opt_nonblock  = { "nonblock",  NULL, OPT_NONBLOCK,  GROUP_OPEN|GROUP_FD, PH_FD, TYPE_BOOL, OFUNC_FCNTL, F_SETFL, O_NONBLOCK };
#if defined(O_NDELAY) && (!defined(O_NONBLOCK) || O_NDELAY != O_NONBLOCK)
const struct optdesc opt_o_ndelay  = { "o_ndelay",  NULL, OPT_O_NDELAY,  GROUP_OPEN|GROUP_FD, PH_LATE, TYPE_BOOL, OFUNC_FCNTL, F_SETFL, O_NDELAY };
#endif
#ifdef O_ASYNC
const struct optdesc opt_async     = { "async",     NULL, OPT_ASYNC,     GROUP_OPEN|GROUP_FD, PH_LATE, TYPE_BOOL, OFUNC_FCNTL, F_SETFL, O_ASYNC };
#endif
/****** for ALL addresses - with fcntl(F_SETFD) ******/
const struct optdesc opt_cloexec   = { "cloexec",   NULL, OPT_CLOEXEC,   GROUP_FD, PH_LATE, TYPE_BOOL, OFUNC_FCNTL, F_SETFD, FD_CLOEXEC };
/****** for ALL addresses - with open() or trunc() or so ******/
const struct optdesc opt_truncate  = { "truncate",  "trunc", OPT_TRUNCATE,  GROUP_OPEN|GROUP_REG, PH_LATE, TYPE_BOOL,	 OFUNC_FLAG, O_TRUNC };
/****** for ALL addresses - permissions, ownership, and positioning ******/
const struct optdesc opt_group     = { "group",     "gid",   OPT_GROUP,     GROUP_FD|GROUP_NAMED,PH_FD,TYPE_GIDT,OFUNC_SPEC };
const struct optdesc opt_group_late= { "group-late","gid-l", OPT_GROUP_LATE,GROUP_FD, PH_LATE,  TYPE_GIDT, OFUNC_SPEC };
const struct optdesc opt_perm      = { "perm",      "mode",  OPT_PERM,      GROUP_FD|GROUP_NAMED, PH_FD,    TYPE_MODET,OFUNC_SPEC };
const struct optdesc opt_perm_late = { "perm-late", NULL,    OPT_PERM_LATE, GROUP_FD, PH_LATE,  TYPE_MODET,OFUNC_SPEC };
const struct optdesc opt_user      = { "user",      "uid",   OPT_USER,      GROUP_FD|GROUP_NAMED, PH_FD,    TYPE_UIDT, OFUNC_SPEC };
const struct optdesc opt_user_late = { "user-late", "uid-l", OPT_USER_LATE, GROUP_FD, PH_LATE,  TYPE_UIDT, OFUNC_SPEC };
const struct optdesc opt_seek_cur  = { "seek-cur",  NULL,    OPT_SEEK_CUR,  GROUP_REG|GROUP_BLK, PH_LATE,  TYPE_LONG, OFUNC_SEEK, SEEK_CUR };
const struct optdesc opt_seek_end  = { "seek-end",  NULL,    OPT_SEEK_END,  GROUP_REG|GROUP_BLK, PH_LATE,  TYPE_LONG, OFUNC_SEEK, SEEK_END };
const struct optdesc opt_seek_set  = { "seek-set",  "seek",  OPT_SEEK_SET,  GROUP_REG|GROUP_BLK, PH_LATE,  TYPE_LONG, OFUNC_SEEK, SEEK_SET };
const struct optdesc opt_f_setlk   = { "f-setlk",   "setlk", OPT_F_SETLK,   GROUP_FD, PH_FD,TYPE_BOOL, OFUNC_SPEC, F_SETLK };
const struct optdesc opt_f_setlkw  = { "f-setlkw",  "setlkw",OPT_F_SETLKW,  GROUP_FD, PH_FD,TYPE_BOOL, OFUNC_SPEC, F_SETLKW };
#if HAVE_FLOCK
const struct optdesc opt_flock     = { "flock",     NULL,    OPT_FLOCK,     GROUP_FD, PH_FD,TYPE_BOOL, OFUNC_SPEC };
#endif /* HAVE_FLOCK */

==> socat-1.1.0.1.tar.bz2: socat-1.1/xio-fd.c <==
static const char _rcsid_[]="$Id: xio-fd.c,v 1.15 2002/06/08 14:54:16 gerhard Exp $";
/* Copyright Gerhard Rieger 2001, 2002 */
/* Published under the GNU General Public License V.2, see file COPYING */

/* this file contains common file descriptor related option definitions */

#include "xiosysincludes.h"
#include "xioopen.h"

#include "xio-fd.h"

/****** for ALL addresses - with open() or fcntl(F_SETFL) ******/
const struct optdesc opt_append    = { "append",    NULL, OPT_APPEND,    GROUP_OPEN|GROUP_FD, PH_LATE, TYPE_BOOL, OFUNC_FCNTL, F_SETFL, O_APPEND };
const struct optdesc opt_nonblock  = { "nonblock",  NULL, OPT_NONBLOCK,  GROUP_OPEN|GROUP_FD, PH_FD, TYPE_BOOL, OFUNC_FCNTL, F_SETFL, O_NONBLOCK };
#if defined(O_NDELAY) && (!defined(O_NONBLOCK) || O_NDELAY != O_NONBLOCK)
const struct optdesc opt_o_ndelay  = { "o-ndelay",  NULL, OPT_O_NDELAY,  GROUP_OPEN|GROUP_FD, PH_LATE, TYPE_BOOL, OFUNC_FCNTL, F_SETFL, O_NDELAY };
#endif
#ifdef O_ASYNC
const struct optdesc opt_async     = { "async",     NULL, OPT_ASYNC,     GROUP_OPEN|GROUP_FD, PH_LATE, TYPE_BOOL, OFUNC_FCNTL, F_SETFL, O_ASYNC };
#endif
/****** for ALL addresses - with fcntl(F_SETFD) ******/
const struct optdesc opt_cloexec   = { "cloexec",   NULL, OPT_CLOEXEC,   GROUP_FD, PH_LATE, TYPE_BOOL, OFUNC_FCNTL, F_SETFD, FD_CLOEXEC };
/****** for ALL addresses - with open() or trunc() or so ******/
const struct optdesc opt_truncate  = { "truncate",  "trunc", OPT_TRUNCATE,  GROUP_OPEN|GROUP_REG, PH_LATE, TYPE_BOOL,	 OFUNC_FLAG, O_TRUNC };
/****** for ALL addresses - permissions, ownership, and positioning ******/
const struct optdesc opt_group     = { "group",     "gid",   OPT_GROUP,     GROUP_FD|GROUP_NAMED,PH_FD,TYPE_GIDT,OFUNC_SPEC };
const struct optdesc opt_group_late= { "group-late","gid-l", OPT_GROUP_LATE,GROUP_FD, PH_LATE,  TYPE_GIDT, OFUNC_SPEC };
const struct optdesc opt_perm      = { "perm",      "mode",  OPT_PERM,      GROUP_FD|GROUP_NAMED, PH_FD,    TYPE_MODET,OFUNC_SPEC };
const struct optdesc opt_perm_late = { "perm-late", NULL,    OPT_PERM_LATE, GROUP_FD, PH_LATE,  TYPE_MODET,OFUNC_SPEC };
const struct optdesc opt_user      = { "user",      "uid",   OPT_USER,      GROUP_FD|GROUP_NAMED, PH_FD,    TYPE_UIDT, OFUNC_SPEC };
const struct optdesc opt_user_late = { "user-late", "uid-l", OPT_USER_LATE, GROUP_FD, PH_LATE,  TYPE_UIDT, OFUNC_SPEC };
const struct optdesc opt_seek_cur  = { "seek-cur",  NULL,    OPT_SEEK_CUR,  GROUP_REG|GROUP_BLK, PH_LATE,  TYPE_LONG, OFUNC_SEEK, SEEK_CUR };
const struct optdesc opt_seek_end  = { "seek-end",  NULL,    OPT_SEEK_END,  GROUP_REG|GROUP_BLK, PH_LATE,  TYPE_LONG, OFUNC_SEEK, SEEK_END };
const struct optdesc opt_seek_set  = { "seek-set",  "seek",  OPT_SEEK_SET,  GROUP_REG|GROUP_BLK, PH_LATE,  TYPE_LONG, OFUNC_SEEK, SEEK_SET };
const struct optdesc opt_f_setlk   = { "f-setlk",   "setlk", OPT_F_SETLK,   GROUP_FD, PH_FD,TYPE_BOOL, OFUNC_SPEC, F_SETLK };
const struct optdesc opt_f_setlkw  = { "f-setlkw",  "setlkw",OPT_F_SETLKW,  GROUP_FD, PH_FD,TYPE_BOOL, OFUNC_SPEC, F_SETLKW };
#if HAVE_FLOCK
const struct optdesc opt_flock     = { "flock",     NULL,    OPT_FLOCK,     GROUP_FD, PH_FD,TYPE_BOOL, OFUNC_SPEC };
#endif /* HAVE_FLOCK */
